# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: proto/tm/replay.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='proto/tm/replay.proto',
  package='vega',
  syntax='proto3',
  serialized_options=b'Z\034code.vegaprotocol.io/vega/tm',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x15proto/tm/replay.proto\x12\x04vega\"\xba\x02\n\x07TmEvent\x12.\n\x0creqInitChain\x18\x01 \x01(\x0b\x32\x16.vega.RequestInitChainH\x00\x12/\n\x0cresInitChain\x18\x02 \x01(\x0b\x32\x17.vega.ResponseInitChainH\x00\x12.\n\x0creqDeliverTx\x18\x03 \x01(\x0b\x32\x16.vega.RequestDeliverTxH\x00\x12/\n\x0cresDeliverTx\x18\x04 \x01(\x0b\x32\x17.vega.ResponseDeliverTxH\x00\x12\x30\n\rreqBeginBlock\x18\x05 \x01(\x0b\x32\x17.vega.RequestBeginBlockH\x00\x12\x31\n\rresBeginBlock\x18\x06 \x01(\x0b\x32\x18.vega.ResponseBeginBlockH\x00\x42\x08\n\x06\x41\x63tion\"\xba\x01\n\x10RequestInitChain\x12\x0c\n\x04time\x18\x01 \x01(\x03\x12\x0f\n\x07\x63hainID\x18\x02 \x01(\t\x12.\n\x0f\x63onsensusParams\x18\x03 \x01(\x0b\x32\x15.vega.ConsensusParams\x12)\n\nvalidators\x18\x04 \x03(\x0b\x32\x15.vega.ValidatorUpdate\x12\x15\n\rappStateBytes\x18\x05 \x01(\x0c\x12\x15\n\rinitialHeight\x18\x06 \x01(\x03\"\x9a\x01\n\x11RequestBeginBlock\x12\x0c\n\x04hash\x18\x01 \x01(\x0c\x12\x1c\n\x06header\x18\x02 \x01(\x0b\x32\x0c.vega.Header\x12,\n\x0elastCommitInfo\x18\x03 \x01(\x0b\x32\x14.vega.LastCommitInfo\x12+\n\x13\x62yzantineValidators\x18\x04 \x03(\x0b\x32\x0e.vega.Evidence\"\x1e\n\x10RequestDeliverTx\x12\n\n\x02tx\x18\x01 \x01(\x0c\"\x7f\n\x11ResponseInitChain\x12.\n\x0f\x63onsensusParams\x18\x01 \x01(\x0b\x32\x15.vega.ConsensusParams\x12)\n\nvalidators\x18\x02 \x03(\x0b\x32\x15.vega.ValidatorUpdate\x12\x0f\n\x07\x61ppHash\x18\x03 \x01(\x0c\"1\n\x12ResponseBeginBlock\x12\x1b\n\x06\x65vents\x18\x01 \x03(\x0b\x32\x0b.vega.Event\"\x9e\x01\n\x11ResponseDeliverTx\x12\x0c\n\x04\x63ode\x18\x01 \x01(\r\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x12\x0b\n\x03log\x18\x03 \x01(\t\x12\x0c\n\x04info\x18\x04 \x01(\t\x12\x11\n\tgasWanted\x18\x05 \x01(\x03\x12\x0f\n\x07gasUsed\x18\x06 \x01(\x03\x12\x1b\n\x06\x65vents\x18\x07 \x03(\x0b\x32\x0b.vega.Event\x12\x11\n\tcodespace\x18\x08 \x01(\t\"?\n\x05\x45vent\x12\x0c\n\x04type\x18\x01 \x01(\t\x12(\n\nattributes\x18\x02 \x03(\x0b\x32\x14.vega.EventAttribute\";\n\x0e\x45ventAttribute\x12\x0b\n\x03key\x18\x01 \x01(\x0c\x12\r\n\x05value\x18\x02 \x01(\x0c\x12\r\n\x05index\x18\x03 \x01(\x08\"B\n\x0fValidatorUpdate\x12 \n\x07pub_key\x18\x01 \x01(\x0b\x32\x0f.vega.PublicKey\x12\r\n\x05power\x18\x02 \x01(\x03\"\xab\x01\n\x0f\x43onsensusParams\x12 \n\x05\x62lock\x18\x01 \x01(\x0b\x32\x11.vega.BlockParams\x12&\n\x08\x65vidence\x18\x02 \x01(\x0b\x32\x14.vega.EvidenceParams\x12(\n\tvalidator\x18\x03 \x01(\x0b\x32\x15.vega.ValidatorParams\x12$\n\x07version\x18\x04 \x01(\x0b\x32\x13.vega.VersionParams\"/\n\x0b\x42lockParams\x12\x10\n\x08maxBytes\x18\x01 \x01(\x03\x12\x0e\n\x06maxGas\x18\x02 \x01(\x03\"\x88\x01\n\x08\x45vidence\x12 \n\x04type\x18\x01 \x01(\x0e\x32\x12.vega.EvidenceType\x12\"\n\tvalidator\x18\x02 \x01(\x0b\x32\x0f.vega.Validator\x12\x0e\n\x06height\x18\x03 \x01(\x03\x12\x0c\n\x04time\x18\x04 \x01(\x03\x12\x18\n\x10totalVotingPower\x18\x05 \x01(\x03\"+\n\tValidator\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0c\x12\r\n\x05power\x18\x03 \x01(\x03\">\n\x0eLastCommitInfo\x12\r\n\x05round\x18\x01 \x01(\x05\x12\x1d\n\x05votes\x18\x02 \x03(\x0b\x32\x0e.vega.VoteInfo\"G\n\x08VoteInfo\x12\"\n\tvalidator\x18\x01 \x01(\x0b\x32\x0f.vega.Validator\x12\x17\n\x0fsignedLastBlock\x18\x02 \x01(\x08\"R\n\x0e\x45videnceParams\x12\x17\n\x0fmaxAgeNumBlocks\x18\x01 \x01(\x03\x12\x16\n\x0emaxAgeDuration\x18\x02 \x01(\x03\x12\x0f\n\x07max_num\x18\x03 \x01(\r\"&\n\x0fValidatorParams\x12\x13\n\x0bpubKeyTypes\x18\x01 \x03(\t\"#\n\rVersionParams\x12\x12\n\nappVersion\x18\x01 \x01(\x04\"7\n\x06Header\x12\x0f\n\x07\x63hainId\x18\x01 \x01(\t\x12\x0e\n\x06height\x18\x02 \x01(\x03\x12\x0c\n\x04time\x18\x03 \x01(\x03\"%\n\tPublicKey\x12\x11\n\x07\x65\x64\x32\x35\x35\x31\x39\x18\x01 \x01(\x0cH\x00\x42\x05\n\x03sum*H\n\x0c\x45videnceType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x12\n\x0e\x44UPLICATE_VOTE\x10\x01\x12\x17\n\x13LIGHT_CLIENT_ATTACK\x10\x02\x42\x1eZ\x1c\x63ode.vegaprotocol.io/vega/tmb\x06proto3'
)

_EVIDENCETYPE = _descriptor.EnumDescriptor(
  name='EvidenceType',
  full_name='vega.EvidenceType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DUPLICATE_VOTE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LIGHT_CLIENT_ATTACK', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2062,
  serialized_end=2134,
)
_sym_db.RegisterEnumDescriptor(_EVIDENCETYPE)

EvidenceType = enum_type_wrapper.EnumTypeWrapper(_EVIDENCETYPE)
UNKNOWN = 0
DUPLICATE_VOTE = 1
LIGHT_CLIENT_ATTACK = 2



_TMEVENT = _descriptor.Descriptor(
  name='TmEvent',
  full_name='vega.TmEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='reqInitChain', full_name='vega.TmEvent.reqInitChain', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resInitChain', full_name='vega.TmEvent.resInitChain', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reqDeliverTx', full_name='vega.TmEvent.reqDeliverTx', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resDeliverTx', full_name='vega.TmEvent.resDeliverTx', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reqBeginBlock', full_name='vega.TmEvent.reqBeginBlock', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resBeginBlock', full_name='vega.TmEvent.resBeginBlock', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='Action', full_name='vega.TmEvent.Action',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=32,
  serialized_end=346,
)


_REQUESTINITCHAIN = _descriptor.Descriptor(
  name='RequestInitChain',
  full_name='vega.RequestInitChain',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time', full_name='vega.RequestInitChain.time', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chainID', full_name='vega.RequestInitChain.chainID', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='consensusParams', full_name='vega.RequestInitChain.consensusParams', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='validators', full_name='vega.RequestInitChain.validators', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='appStateBytes', full_name='vega.RequestInitChain.appStateBytes', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='initialHeight', full_name='vega.RequestInitChain.initialHeight', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=349,
  serialized_end=535,
)


_REQUESTBEGINBLOCK = _descriptor.Descriptor(
  name='RequestBeginBlock',
  full_name='vega.RequestBeginBlock',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='hash', full_name='vega.RequestBeginBlock.hash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='header', full_name='vega.RequestBeginBlock.header', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lastCommitInfo', full_name='vega.RequestBeginBlock.lastCommitInfo', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='byzantineValidators', full_name='vega.RequestBeginBlock.byzantineValidators', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=538,
  serialized_end=692,
)


_REQUESTDELIVERTX = _descriptor.Descriptor(
  name='RequestDeliverTx',
  full_name='vega.RequestDeliverTx',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tx', full_name='vega.RequestDeliverTx.tx', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=694,
  serialized_end=724,
)


_RESPONSEINITCHAIN = _descriptor.Descriptor(
  name='ResponseInitChain',
  full_name='vega.ResponseInitChain',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='consensusParams', full_name='vega.ResponseInitChain.consensusParams', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='validators', full_name='vega.ResponseInitChain.validators', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='appHash', full_name='vega.ResponseInitChain.appHash', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=726,
  serialized_end=853,
)


_RESPONSEBEGINBLOCK = _descriptor.Descriptor(
  name='ResponseBeginBlock',
  full_name='vega.ResponseBeginBlock',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='events', full_name='vega.ResponseBeginBlock.events', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=855,
  serialized_end=904,
)


_RESPONSEDELIVERTX = _descriptor.Descriptor(
  name='ResponseDeliverTx',
  full_name='vega.ResponseDeliverTx',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='vega.ResponseDeliverTx.code', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='vega.ResponseDeliverTx.data', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='log', full_name='vega.ResponseDeliverTx.log', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='info', full_name='vega.ResponseDeliverTx.info', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gasWanted', full_name='vega.ResponseDeliverTx.gasWanted', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gasUsed', full_name='vega.ResponseDeliverTx.gasUsed', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='events', full_name='vega.ResponseDeliverTx.events', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='codespace', full_name='vega.ResponseDeliverTx.codespace', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=907,
  serialized_end=1065,
)


_EVENT = _descriptor.Descriptor(
  name='Event',
  full_name='vega.Event',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='vega.Event.type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attributes', full_name='vega.Event.attributes', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1067,
  serialized_end=1130,
)


_EVENTATTRIBUTE = _descriptor.Descriptor(
  name='EventAttribute',
  full_name='vega.EventAttribute',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='vega.EventAttribute.key', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='vega.EventAttribute.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='index', full_name='vega.EventAttribute.index', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1132,
  serialized_end=1191,
)


_VALIDATORUPDATE = _descriptor.Descriptor(
  name='ValidatorUpdate',
  full_name='vega.ValidatorUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pub_key', full_name='vega.ValidatorUpdate.pub_key', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='power', full_name='vega.ValidatorUpdate.power', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1193,
  serialized_end=1259,
)


_CONSENSUSPARAMS = _descriptor.Descriptor(
  name='ConsensusParams',
  full_name='vega.ConsensusParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='block', full_name='vega.ConsensusParams.block', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='evidence', full_name='vega.ConsensusParams.evidence', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='validator', full_name='vega.ConsensusParams.validator', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='vega.ConsensusParams.version', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1262,
  serialized_end=1433,
)


_BLOCKPARAMS = _descriptor.Descriptor(
  name='BlockParams',
  full_name='vega.BlockParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='maxBytes', full_name='vega.BlockParams.maxBytes', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maxGas', full_name='vega.BlockParams.maxGas', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1435,
  serialized_end=1482,
)


_EVIDENCE = _descriptor.Descriptor(
  name='Evidence',
  full_name='vega.Evidence',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='vega.Evidence.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='validator', full_name='vega.Evidence.validator', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='height', full_name='vega.Evidence.height', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time', full_name='vega.Evidence.time', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='totalVotingPower', full_name='vega.Evidence.totalVotingPower', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1485,
  serialized_end=1621,
)


_VALIDATOR = _descriptor.Descriptor(
  name='Validator',
  full_name='vega.Validator',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='vega.Validator.address', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='power', full_name='vega.Validator.power', index=1,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1623,
  serialized_end=1666,
)


_LASTCOMMITINFO = _descriptor.Descriptor(
  name='LastCommitInfo',
  full_name='vega.LastCommitInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='round', full_name='vega.LastCommitInfo.round', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='votes', full_name='vega.LastCommitInfo.votes', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1668,
  serialized_end=1730,
)


_VOTEINFO = _descriptor.Descriptor(
  name='VoteInfo',
  full_name='vega.VoteInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='validator', full_name='vega.VoteInfo.validator', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signedLastBlock', full_name='vega.VoteInfo.signedLastBlock', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1732,
  serialized_end=1803,
)


_EVIDENCEPARAMS = _descriptor.Descriptor(
  name='EvidenceParams',
  full_name='vega.EvidenceParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='maxAgeNumBlocks', full_name='vega.EvidenceParams.maxAgeNumBlocks', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maxAgeDuration', full_name='vega.EvidenceParams.maxAgeDuration', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_num', full_name='vega.EvidenceParams.max_num', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1805,
  serialized_end=1887,
)


_VALIDATORPARAMS = _descriptor.Descriptor(
  name='ValidatorParams',
  full_name='vega.ValidatorParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pubKeyTypes', full_name='vega.ValidatorParams.pubKeyTypes', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1889,
  serialized_end=1927,
)


_VERSIONPARAMS = _descriptor.Descriptor(
  name='VersionParams',
  full_name='vega.VersionParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appVersion', full_name='vega.VersionParams.appVersion', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1929,
  serialized_end=1964,
)


_HEADER = _descriptor.Descriptor(
  name='Header',
  full_name='vega.Header',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chainId', full_name='vega.Header.chainId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='height', full_name='vega.Header.height', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time', full_name='vega.Header.time', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1966,
  serialized_end=2021,
)


_PUBLICKEY = _descriptor.Descriptor(
  name='PublicKey',
  full_name='vega.PublicKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ed25519', full_name='vega.PublicKey.ed25519', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='sum', full_name='vega.PublicKey.sum',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2023,
  serialized_end=2060,
)

_TMEVENT.fields_by_name['reqInitChain'].message_type = _REQUESTINITCHAIN
_TMEVENT.fields_by_name['resInitChain'].message_type = _RESPONSEINITCHAIN
_TMEVENT.fields_by_name['reqDeliverTx'].message_type = _REQUESTDELIVERTX
_TMEVENT.fields_by_name['resDeliverTx'].message_type = _RESPONSEDELIVERTX
_TMEVENT.fields_by_name['reqBeginBlock'].message_type = _REQUESTBEGINBLOCK
_TMEVENT.fields_by_name['resBeginBlock'].message_type = _RESPONSEBEGINBLOCK
_TMEVENT.oneofs_by_name['Action'].fields.append(
  _TMEVENT.fields_by_name['reqInitChain'])
_TMEVENT.fields_by_name['reqInitChain'].containing_oneof = _TMEVENT.oneofs_by_name['Action']
_TMEVENT.oneofs_by_name['Action'].fields.append(
  _TMEVENT.fields_by_name['resInitChain'])
_TMEVENT.fields_by_name['resInitChain'].containing_oneof = _TMEVENT.oneofs_by_name['Action']
_TMEVENT.oneofs_by_name['Action'].fields.append(
  _TMEVENT.fields_by_name['reqDeliverTx'])
_TMEVENT.fields_by_name['reqDeliverTx'].containing_oneof = _TMEVENT.oneofs_by_name['Action']
_TMEVENT.oneofs_by_name['Action'].fields.append(
  _TMEVENT.fields_by_name['resDeliverTx'])
_TMEVENT.fields_by_name['resDeliverTx'].containing_oneof = _TMEVENT.oneofs_by_name['Action']
_TMEVENT.oneofs_by_name['Action'].fields.append(
  _TMEVENT.fields_by_name['reqBeginBlock'])
_TMEVENT.fields_by_name['reqBeginBlock'].containing_oneof = _TMEVENT.oneofs_by_name['Action']
_TMEVENT.oneofs_by_name['Action'].fields.append(
  _TMEVENT.fields_by_name['resBeginBlock'])
_TMEVENT.fields_by_name['resBeginBlock'].containing_oneof = _TMEVENT.oneofs_by_name['Action']
_REQUESTINITCHAIN.fields_by_name['consensusParams'].message_type = _CONSENSUSPARAMS
_REQUESTINITCHAIN.fields_by_name['validators'].message_type = _VALIDATORUPDATE
_REQUESTBEGINBLOCK.fields_by_name['header'].message_type = _HEADER
_REQUESTBEGINBLOCK.fields_by_name['lastCommitInfo'].message_type = _LASTCOMMITINFO
_REQUESTBEGINBLOCK.fields_by_name['byzantineValidators'].message_type = _EVIDENCE
_RESPONSEINITCHAIN.fields_by_name['consensusParams'].message_type = _CONSENSUSPARAMS
_RESPONSEINITCHAIN.fields_by_name['validators'].message_type = _VALIDATORUPDATE
_RESPONSEBEGINBLOCK.fields_by_name['events'].message_type = _EVENT
_RESPONSEDELIVERTX.fields_by_name['events'].message_type = _EVENT
_EVENT.fields_by_name['attributes'].message_type = _EVENTATTRIBUTE
_VALIDATORUPDATE.fields_by_name['pub_key'].message_type = _PUBLICKEY
_CONSENSUSPARAMS.fields_by_name['block'].message_type = _BLOCKPARAMS
_CONSENSUSPARAMS.fields_by_name['evidence'].message_type = _EVIDENCEPARAMS
_CONSENSUSPARAMS.fields_by_name['validator'].message_type = _VALIDATORPARAMS
_CONSENSUSPARAMS.fields_by_name['version'].message_type = _VERSIONPARAMS
_EVIDENCE.fields_by_name['type'].enum_type = _EVIDENCETYPE
_EVIDENCE.fields_by_name['validator'].message_type = _VALIDATOR
_LASTCOMMITINFO.fields_by_name['votes'].message_type = _VOTEINFO
_VOTEINFO.fields_by_name['validator'].message_type = _VALIDATOR
_PUBLICKEY.oneofs_by_name['sum'].fields.append(
  _PUBLICKEY.fields_by_name['ed25519'])
_PUBLICKEY.fields_by_name['ed25519'].containing_oneof = _PUBLICKEY.oneofs_by_name['sum']
DESCRIPTOR.message_types_by_name['TmEvent'] = _TMEVENT
DESCRIPTOR.message_types_by_name['RequestInitChain'] = _REQUESTINITCHAIN
DESCRIPTOR.message_types_by_name['RequestBeginBlock'] = _REQUESTBEGINBLOCK
DESCRIPTOR.message_types_by_name['RequestDeliverTx'] = _REQUESTDELIVERTX
DESCRIPTOR.message_types_by_name['ResponseInitChain'] = _RESPONSEINITCHAIN
DESCRIPTOR.message_types_by_name['ResponseBeginBlock'] = _RESPONSEBEGINBLOCK
DESCRIPTOR.message_types_by_name['ResponseDeliverTx'] = _RESPONSEDELIVERTX
DESCRIPTOR.message_types_by_name['Event'] = _EVENT
DESCRIPTOR.message_types_by_name['EventAttribute'] = _EVENTATTRIBUTE
DESCRIPTOR.message_types_by_name['ValidatorUpdate'] = _VALIDATORUPDATE
DESCRIPTOR.message_types_by_name['ConsensusParams'] = _CONSENSUSPARAMS
DESCRIPTOR.message_types_by_name['BlockParams'] = _BLOCKPARAMS
DESCRIPTOR.message_types_by_name['Evidence'] = _EVIDENCE
DESCRIPTOR.message_types_by_name['Validator'] = _VALIDATOR
DESCRIPTOR.message_types_by_name['LastCommitInfo'] = _LASTCOMMITINFO
DESCRIPTOR.message_types_by_name['VoteInfo'] = _VOTEINFO
DESCRIPTOR.message_types_by_name['EvidenceParams'] = _EVIDENCEPARAMS
DESCRIPTOR.message_types_by_name['ValidatorParams'] = _VALIDATORPARAMS
DESCRIPTOR.message_types_by_name['VersionParams'] = _VERSIONPARAMS
DESCRIPTOR.message_types_by_name['Header'] = _HEADER
DESCRIPTOR.message_types_by_name['PublicKey'] = _PUBLICKEY
DESCRIPTOR.enum_types_by_name['EvidenceType'] = _EVIDENCETYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TmEvent = _reflection.GeneratedProtocolMessageType('TmEvent', (_message.Message,), {
  'DESCRIPTOR' : _TMEVENT,
  '__module__' : 'proto.tm.replay_pb2'
  # @@protoc_insertion_point(class_scope:vega.TmEvent)
  })
_sym_db.RegisterMessage(TmEvent)

RequestInitChain = _reflection.GeneratedProtocolMessageType('RequestInitChain', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTINITCHAIN,
  '__module__' : 'proto.tm.replay_pb2'
  # @@protoc_insertion_point(class_scope:vega.RequestInitChain)
  })
_sym_db.RegisterMessage(RequestInitChain)

RequestBeginBlock = _reflection.GeneratedProtocolMessageType('RequestBeginBlock', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTBEGINBLOCK,
  '__module__' : 'proto.tm.replay_pb2'
  # @@protoc_insertion_point(class_scope:vega.RequestBeginBlock)
  })
_sym_db.RegisterMessage(RequestBeginBlock)

RequestDeliverTx = _reflection.GeneratedProtocolMessageType('RequestDeliverTx', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTDELIVERTX,
  '__module__' : 'proto.tm.replay_pb2'
  # @@protoc_insertion_point(class_scope:vega.RequestDeliverTx)
  })
_sym_db.RegisterMessage(RequestDeliverTx)

ResponseInitChain = _reflection.GeneratedProtocolMessageType('ResponseInitChain', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSEINITCHAIN,
  '__module__' : 'proto.tm.replay_pb2'
  # @@protoc_insertion_point(class_scope:vega.ResponseInitChain)
  })
_sym_db.RegisterMessage(ResponseInitChain)

ResponseBeginBlock = _reflection.GeneratedProtocolMessageType('ResponseBeginBlock', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSEBEGINBLOCK,
  '__module__' : 'proto.tm.replay_pb2'
  # @@protoc_insertion_point(class_scope:vega.ResponseBeginBlock)
  })
_sym_db.RegisterMessage(ResponseBeginBlock)

ResponseDeliverTx = _reflection.GeneratedProtocolMessageType('ResponseDeliverTx', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSEDELIVERTX,
  '__module__' : 'proto.tm.replay_pb2'
  # @@protoc_insertion_point(class_scope:vega.ResponseDeliverTx)
  })
_sym_db.RegisterMessage(ResponseDeliverTx)

Event = _reflection.GeneratedProtocolMessageType('Event', (_message.Message,), {
  'DESCRIPTOR' : _EVENT,
  '__module__' : 'proto.tm.replay_pb2'
  # @@protoc_insertion_point(class_scope:vega.Event)
  })
_sym_db.RegisterMessage(Event)

EventAttribute = _reflection.GeneratedProtocolMessageType('EventAttribute', (_message.Message,), {
  'DESCRIPTOR' : _EVENTATTRIBUTE,
  '__module__' : 'proto.tm.replay_pb2'
  # @@protoc_insertion_point(class_scope:vega.EventAttribute)
  })
_sym_db.RegisterMessage(EventAttribute)

ValidatorUpdate = _reflection.GeneratedProtocolMessageType('ValidatorUpdate', (_message.Message,), {
  'DESCRIPTOR' : _VALIDATORUPDATE,
  '__module__' : 'proto.tm.replay_pb2'
  # @@protoc_insertion_point(class_scope:vega.ValidatorUpdate)
  })
_sym_db.RegisterMessage(ValidatorUpdate)

ConsensusParams = _reflection.GeneratedProtocolMessageType('ConsensusParams', (_message.Message,), {
  'DESCRIPTOR' : _CONSENSUSPARAMS,
  '__module__' : 'proto.tm.replay_pb2'
  # @@protoc_insertion_point(class_scope:vega.ConsensusParams)
  })
_sym_db.RegisterMessage(ConsensusParams)

BlockParams = _reflection.GeneratedProtocolMessageType('BlockParams', (_message.Message,), {
  'DESCRIPTOR' : _BLOCKPARAMS,
  '__module__' : 'proto.tm.replay_pb2'
  # @@protoc_insertion_point(class_scope:vega.BlockParams)
  })
_sym_db.RegisterMessage(BlockParams)

Evidence = _reflection.GeneratedProtocolMessageType('Evidence', (_message.Message,), {
  'DESCRIPTOR' : _EVIDENCE,
  '__module__' : 'proto.tm.replay_pb2'
  # @@protoc_insertion_point(class_scope:vega.Evidence)
  })
_sym_db.RegisterMessage(Evidence)

Validator = _reflection.GeneratedProtocolMessageType('Validator', (_message.Message,), {
  'DESCRIPTOR' : _VALIDATOR,
  '__module__' : 'proto.tm.replay_pb2'
  # @@protoc_insertion_point(class_scope:vega.Validator)
  })
_sym_db.RegisterMessage(Validator)

LastCommitInfo = _reflection.GeneratedProtocolMessageType('LastCommitInfo', (_message.Message,), {
  'DESCRIPTOR' : _LASTCOMMITINFO,
  '__module__' : 'proto.tm.replay_pb2'
  # @@protoc_insertion_point(class_scope:vega.LastCommitInfo)
  })
_sym_db.RegisterMessage(LastCommitInfo)

VoteInfo = _reflection.GeneratedProtocolMessageType('VoteInfo', (_message.Message,), {
  'DESCRIPTOR' : _VOTEINFO,
  '__module__' : 'proto.tm.replay_pb2'
  # @@protoc_insertion_point(class_scope:vega.VoteInfo)
  })
_sym_db.RegisterMessage(VoteInfo)

EvidenceParams = _reflection.GeneratedProtocolMessageType('EvidenceParams', (_message.Message,), {
  'DESCRIPTOR' : _EVIDENCEPARAMS,
  '__module__' : 'proto.tm.replay_pb2'
  # @@protoc_insertion_point(class_scope:vega.EvidenceParams)
  })
_sym_db.RegisterMessage(EvidenceParams)

ValidatorParams = _reflection.GeneratedProtocolMessageType('ValidatorParams', (_message.Message,), {
  'DESCRIPTOR' : _VALIDATORPARAMS,
  '__module__' : 'proto.tm.replay_pb2'
  # @@protoc_insertion_point(class_scope:vega.ValidatorParams)
  })
_sym_db.RegisterMessage(ValidatorParams)

VersionParams = _reflection.GeneratedProtocolMessageType('VersionParams', (_message.Message,), {
  'DESCRIPTOR' : _VERSIONPARAMS,
  '__module__' : 'proto.tm.replay_pb2'
  # @@protoc_insertion_point(class_scope:vega.VersionParams)
  })
_sym_db.RegisterMessage(VersionParams)

Header = _reflection.GeneratedProtocolMessageType('Header', (_message.Message,), {
  'DESCRIPTOR' : _HEADER,
  '__module__' : 'proto.tm.replay_pb2'
  # @@protoc_insertion_point(class_scope:vega.Header)
  })
_sym_db.RegisterMessage(Header)

PublicKey = _reflection.GeneratedProtocolMessageType('PublicKey', (_message.Message,), {
  'DESCRIPTOR' : _PUBLICKEY,
  '__module__' : 'proto.tm.replay_pb2'
  # @@protoc_insertion_point(class_scope:vega.PublicKey)
  })
_sym_db.RegisterMessage(PublicKey)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
