# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: proto/events.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import markets_pb2 as proto_dot_markets__pb2
from . import assets_pb2 as proto_dot_assets__pb2
from . import governance_pb2 as proto_dot_governance__pb2
from . import vega_pb2 as proto_dot_vega__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='proto/events.proto',
  package='vega',
  syntax='proto3',
  serialized_options=b'Z\037code.vegaprotocol.io/vega/proto',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x12proto/events.proto\x12\x04vega\x1a\x13proto/markets.proto\x1a\x12proto/assets.proto\x1a\x16proto/governance.proto\x1a\x10proto/vega.proto\"0\n\x0bMarketEvent\x12\x10\n\x08marketID\x18\x01 \x01(\t\x12\x0f\n\x07payload\x18\x02 \x01(\t\"\x1f\n\nTimeUpdate\x12\x11\n\ttimestamp\x18\x01 \x01(\x03\">\n\x11TransferResponses\x12)\n\tresponses\x18\x01 \x03(\x0b\x32\x16.vega.TransferResponse\"]\n\x12PositionResolution\x12\x10\n\x08marketID\x18\x01 \x01(\t\x12\x12\n\ndistressed\x18\x02 \x01(\x03\x12\x0e\n\x06\x63losed\x18\x03 \x01(\x03\x12\x11\n\tmarkPrice\x18\x04 \x01(\x04\"F\n\x11LossSocialization\x12\x10\n\x08marketID\x18\x01 \x01(\t\x12\x0f\n\x07partyID\x18\x02 \x01(\t\x12\x0e\n\x06\x61mount\x18\x03 \x01(\x03\".\n\x0fTradeSettlement\x12\x0c\n\x04size\x18\x01 \x01(\x03\x12\r\n\x05price\x18\x02 \x01(\x04\"s\n\x0eSettlePosition\x12\x10\n\x08marketID\x18\x01 \x01(\t\x12\x0f\n\x07partyID\x18\x02 \x01(\t\x12\r\n\x05price\x18\x03 \x01(\x04\x12/\n\x10tradeSettlements\x18\x04 \x03(\x0b\x32\x15.vega.TradeSettlement\"T\n\x10SettleDistressed\x12\x10\n\x08marketID\x18\x01 \x01(\t\x12\x0f\n\x07partyID\x18\x02 \x01(\t\x12\x0e\n\x06margin\x18\x03 \x01(\x04\x12\r\n\x05price\x18\x04 \x01(\x04\"&\n\nMarketTick\x12\n\n\x02ID\x18\x01 \x01(\t\x12\x0c\n\x04time\x18\x02 \x01(\x03\"\x8a\x01\n\x0c\x41uctionEvent\x12\x10\n\x08marketID\x18\x01 \x01(\t\x12\x16\n\x0eopeningAuction\x18\x02 \x01(\x08\x12\r\n\x05leave\x18\x03 \x01(\x08\x12\r\n\x05start\x18\x04 \x01(\x03\x12\x0b\n\x03\x65nd\x18\x05 \x01(\x03\x12%\n\x07trigger\x18\x06 \x01(\x0e\x32\x14.vega.AuctionTrigger\"\x9e\x08\n\x08\x42usEvent\x12\n\n\x02ID\x18\x01 \x01(\t\x12\r\n\x05\x62lock\x18\x02 \x01(\t\x12 \n\x04type\x18\x03 \x01(\x0e\x32\x12.vega.BusEventType\x12&\n\ntimeUpdate\x18\x65 \x01(\x0b\x32\x10.vega.TimeUpdateH\x00\x12\x34\n\x11transferResponses\x18\x66 \x01(\x0b\x32\x17.vega.TransferResponsesH\x00\x12\x36\n\x12positionResolution\x18g \x01(\x0b\x32\x18.vega.PositionResolutionH\x00\x12\x1c\n\x05order\x18h \x01(\x0b\x32\x0b.vega.OrderH\x00\x12 \n\x07\x61\x63\x63ount\x18i \x01(\x0b\x32\r.vega.AccountH\x00\x12\x1c\n\x05party\x18j \x01(\x0b\x32\x0b.vega.PartyH\x00\x12\x1c\n\x05trade\x18k \x01(\x0b\x32\x0b.vega.TradeH\x00\x12*\n\x0cmarginLevels\x18l \x01(\x0b\x32\x12.vega.MarginLevelsH\x00\x12\"\n\x08proposal\x18m \x01(\x0b\x32\x0e.vega.ProposalH\x00\x12\x1a\n\x04vote\x18n \x01(\x0b\x32\n.vega.VoteH\x00\x12&\n\nmarketData\x18o \x01(\x0b\x32\x10.vega.MarketDataH\x00\x12,\n\rnodeSignature\x18p \x01(\x0b\x32\x13.vega.NodeSignatureH\x00\x12\x34\n\x11lossSocialization\x18q \x01(\x0b\x32\x17.vega.LossSocializationH\x00\x12.\n\x0esettlePosition\x18r \x01(\x0b\x32\x14.vega.SettlePositionH\x00\x12\x32\n\x10settleDistressed\x18s \x01(\x0b\x32\x16.vega.SettleDistressedH\x00\x12%\n\rmarketCreated\x18t \x01(\x0b\x32\x0c.vega.MarketH\x00\x12\x1c\n\x05\x61sset\x18u \x01(\x0b\x32\x0b.vega.AssetH\x00\x12&\n\nmarketTick\x18v \x01(\x0b\x32\x10.vega.MarketTickH\x00\x12&\n\nwithdrawal\x18w \x01(\x0b\x32\x10.vega.WithdrawalH\x00\x12 \n\x07\x64\x65posit\x18x \x01(\x0b\x32\r.vega.DepositH\x00\x12%\n\x07\x61uction\x18y \x01(\x0b\x32\x12.vega.AuctionEventH\x00\x12&\n\nriskFactor\x18z \x01(\x0b\x32\x10.vega.RiskFactorH\x00\x12\x32\n\x10networkParameter\x18{ \x01(\x0b\x32\x16.vega.NetworkParameterH\x00\x12$\n\x06market\x18\xe9\x07 \x01(\x0b\x32\x11.vega.MarketEventH\x00\x42\x07\n\x05\x65vent*\xc0\x06\n\x0c\x42usEventType\x12\x1e\n\x1a\x42US_EVENT_TYPE_UNSPECIFIED\x10\x00\x12\x16\n\x12\x42US_EVENT_TYPE_ALL\x10\x01\x12\x1e\n\x1a\x42US_EVENT_TYPE_TIME_UPDATE\x10\x02\x12%\n!BUS_EVENT_TYPE_TRANSFER_RESPONSES\x10\x03\x12&\n\"BUS_EVENT_TYPE_POSITION_RESOLUTION\x10\x04\x12\x18\n\x14\x42US_EVENT_TYPE_ORDER\x10\x05\x12\x1a\n\x16\x42US_EVENT_TYPE_ACCOUNT\x10\x06\x12\x18\n\x14\x42US_EVENT_TYPE_PARTY\x10\x07\x12\x18\n\x14\x42US_EVENT_TYPE_TRADE\x10\x08\x12 \n\x1c\x42US_EVENT_TYPE_MARGIN_LEVELS\x10\t\x12\x1b\n\x17\x42US_EVENT_TYPE_PROPOSAL\x10\n\x12\x17\n\x13\x42US_EVENT_TYPE_VOTE\x10\x0b\x12\x1e\n\x1a\x42US_EVENT_TYPE_MARKET_DATA\x10\x0c\x12!\n\x1d\x42US_EVENT_TYPE_NODE_SIGNATURE\x10\r\x12%\n!BUS_EVENT_TYPE_LOSS_SOCIALIZATION\x10\x0e\x12\"\n\x1e\x42US_EVENT_TYPE_SETTLE_POSITION\x10\x0f\x12$\n BUS_EVENT_TYPE_SETTLE_DISTRESSED\x10\x10\x12!\n\x1d\x42US_EVENT_TYPE_MARKET_CREATED\x10\x11\x12\x18\n\x14\x42US_EVENT_TYPE_ASSET\x10\x12\x12\x1e\n\x1a\x42US_EVENT_TYPE_MARKET_TICK\x10\x13\x12\x1d\n\x19\x42US_EVENT_TYPE_WITHDRAWAL\x10\x14\x12\x1a\n\x16\x42US_EVENT_TYPE_DEPOSIT\x10\x15\x12\x1a\n\x16\x42US_EVENT_TYPE_AUCTION\x10\x16\x12\x1e\n\x1a\x42US_EVENT_TYPE_RISK_FACTOR\x10\x17\x12$\n BUS_EVENT_TYPE_NETWORK_PARAMETER\x10\x18\x12\x19\n\x15\x42US_EVENT_TYPE_MARKET\x10\x65\x42!Z\x1f\x63ode.vegaprotocol.io/vega/protob\x06proto3'
  ,
  dependencies=[proto_dot_markets__pb2.DESCRIPTOR,proto_dot_assets__pb2.DESCRIPTOR,proto_dot_governance__pb2.DESCRIPTOR,proto_dot_vega__pb2.DESCRIPTOR,])

_BUSEVENTTYPE = _descriptor.EnumDescriptor(
  name='BusEventType',
  full_name='vega.BusEventType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BUS_EVENT_TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUS_EVENT_TYPE_ALL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUS_EVENT_TYPE_TIME_UPDATE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUS_EVENT_TYPE_TRANSFER_RESPONSES', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUS_EVENT_TYPE_POSITION_RESOLUTION', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUS_EVENT_TYPE_ORDER', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUS_EVENT_TYPE_ACCOUNT', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUS_EVENT_TYPE_PARTY', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUS_EVENT_TYPE_TRADE', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUS_EVENT_TYPE_MARGIN_LEVELS', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUS_EVENT_TYPE_PROPOSAL', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUS_EVENT_TYPE_VOTE', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUS_EVENT_TYPE_MARKET_DATA', index=12, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUS_EVENT_TYPE_NODE_SIGNATURE', index=13, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUS_EVENT_TYPE_LOSS_SOCIALIZATION', index=14, number=14,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUS_EVENT_TYPE_SETTLE_POSITION', index=15, number=15,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUS_EVENT_TYPE_SETTLE_DISTRESSED', index=16, number=16,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUS_EVENT_TYPE_MARKET_CREATED', index=17, number=17,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUS_EVENT_TYPE_ASSET', index=18, number=18,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUS_EVENT_TYPE_MARKET_TICK', index=19, number=19,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUS_EVENT_TYPE_WITHDRAWAL', index=20, number=20,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUS_EVENT_TYPE_DEPOSIT', index=21, number=21,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUS_EVENT_TYPE_AUCTION', index=22, number=22,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUS_EVENT_TYPE_RISK_FACTOR', index=23, number=23,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUS_EVENT_TYPE_NETWORK_PARAMETER', index=24, number=24,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUS_EVENT_TYPE_MARKET', index=25, number=101,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1915,
  serialized_end=2747,
)
_sym_db.RegisterEnumDescriptor(_BUSEVENTTYPE)

BusEventType = enum_type_wrapper.EnumTypeWrapper(_BUSEVENTTYPE)
BUS_EVENT_TYPE_UNSPECIFIED = 0
BUS_EVENT_TYPE_ALL = 1
BUS_EVENT_TYPE_TIME_UPDATE = 2
BUS_EVENT_TYPE_TRANSFER_RESPONSES = 3
BUS_EVENT_TYPE_POSITION_RESOLUTION = 4
BUS_EVENT_TYPE_ORDER = 5
BUS_EVENT_TYPE_ACCOUNT = 6
BUS_EVENT_TYPE_PARTY = 7
BUS_EVENT_TYPE_TRADE = 8
BUS_EVENT_TYPE_MARGIN_LEVELS = 9
BUS_EVENT_TYPE_PROPOSAL = 10
BUS_EVENT_TYPE_VOTE = 11
BUS_EVENT_TYPE_MARKET_DATA = 12
BUS_EVENT_TYPE_NODE_SIGNATURE = 13
BUS_EVENT_TYPE_LOSS_SOCIALIZATION = 14
BUS_EVENT_TYPE_SETTLE_POSITION = 15
BUS_EVENT_TYPE_SETTLE_DISTRESSED = 16
BUS_EVENT_TYPE_MARKET_CREATED = 17
BUS_EVENT_TYPE_ASSET = 18
BUS_EVENT_TYPE_MARKET_TICK = 19
BUS_EVENT_TYPE_WITHDRAWAL = 20
BUS_EVENT_TYPE_DEPOSIT = 21
BUS_EVENT_TYPE_AUCTION = 22
BUS_EVENT_TYPE_RISK_FACTOR = 23
BUS_EVENT_TYPE_NETWORK_PARAMETER = 24
BUS_EVENT_TYPE_MARKET = 101



_MARKETEVENT = _descriptor.Descriptor(
  name='MarketEvent',
  full_name='vega.MarketEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='marketID', full_name='vega.MarketEvent.marketID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payload', full_name='vega.MarketEvent.payload', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=111,
  serialized_end=159,
)


_TIMEUPDATE = _descriptor.Descriptor(
  name='TimeUpdate',
  full_name='vega.TimeUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='vega.TimeUpdate.timestamp', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=161,
  serialized_end=192,
)


_TRANSFERRESPONSES = _descriptor.Descriptor(
  name='TransferResponses',
  full_name='vega.TransferResponses',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='responses', full_name='vega.TransferResponses.responses', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=194,
  serialized_end=256,
)


_POSITIONRESOLUTION = _descriptor.Descriptor(
  name='PositionResolution',
  full_name='vega.PositionResolution',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='marketID', full_name='vega.PositionResolution.marketID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='distressed', full_name='vega.PositionResolution.distressed', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='closed', full_name='vega.PositionResolution.closed', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='markPrice', full_name='vega.PositionResolution.markPrice', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=258,
  serialized_end=351,
)


_LOSSSOCIALIZATION = _descriptor.Descriptor(
  name='LossSocialization',
  full_name='vega.LossSocialization',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='marketID', full_name='vega.LossSocialization.marketID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partyID', full_name='vega.LossSocialization.partyID', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='vega.LossSocialization.amount', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=353,
  serialized_end=423,
)


_TRADESETTLEMENT = _descriptor.Descriptor(
  name='TradeSettlement',
  full_name='vega.TradeSettlement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='size', full_name='vega.TradeSettlement.size', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price', full_name='vega.TradeSettlement.price', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=425,
  serialized_end=471,
)


_SETTLEPOSITION = _descriptor.Descriptor(
  name='SettlePosition',
  full_name='vega.SettlePosition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='marketID', full_name='vega.SettlePosition.marketID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partyID', full_name='vega.SettlePosition.partyID', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price', full_name='vega.SettlePosition.price', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tradeSettlements', full_name='vega.SettlePosition.tradeSettlements', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=473,
  serialized_end=588,
)


_SETTLEDISTRESSED = _descriptor.Descriptor(
  name='SettleDistressed',
  full_name='vega.SettleDistressed',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='marketID', full_name='vega.SettleDistressed.marketID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partyID', full_name='vega.SettleDistressed.partyID', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='margin', full_name='vega.SettleDistressed.margin', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price', full_name='vega.SettleDistressed.price', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=590,
  serialized_end=674,
)


_MARKETTICK = _descriptor.Descriptor(
  name='MarketTick',
  full_name='vega.MarketTick',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ID', full_name='vega.MarketTick.ID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time', full_name='vega.MarketTick.time', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=676,
  serialized_end=714,
)


_AUCTIONEVENT = _descriptor.Descriptor(
  name='AuctionEvent',
  full_name='vega.AuctionEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='marketID', full_name='vega.AuctionEvent.marketID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='openingAuction', full_name='vega.AuctionEvent.openingAuction', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='leave', full_name='vega.AuctionEvent.leave', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start', full_name='vega.AuctionEvent.start', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end', full_name='vega.AuctionEvent.end', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trigger', full_name='vega.AuctionEvent.trigger', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=717,
  serialized_end=855,
)


_BUSEVENT = _descriptor.Descriptor(
  name='BusEvent',
  full_name='vega.BusEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ID', full_name='vega.BusEvent.ID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='block', full_name='vega.BusEvent.block', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='vega.BusEvent.type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeUpdate', full_name='vega.BusEvent.timeUpdate', index=3,
      number=101, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transferResponses', full_name='vega.BusEvent.transferResponses', index=4,
      number=102, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='positionResolution', full_name='vega.BusEvent.positionResolution', index=5,
      number=103, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order', full_name='vega.BusEvent.order', index=6,
      number=104, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='account', full_name='vega.BusEvent.account', index=7,
      number=105, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='party', full_name='vega.BusEvent.party', index=8,
      number=106, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trade', full_name='vega.BusEvent.trade', index=9,
      number=107, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='marginLevels', full_name='vega.BusEvent.marginLevels', index=10,
      number=108, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proposal', full_name='vega.BusEvent.proposal', index=11,
      number=109, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vote', full_name='vega.BusEvent.vote', index=12,
      number=110, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='marketData', full_name='vega.BusEvent.marketData', index=13,
      number=111, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nodeSignature', full_name='vega.BusEvent.nodeSignature', index=14,
      number=112, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lossSocialization', full_name='vega.BusEvent.lossSocialization', index=15,
      number=113, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='settlePosition', full_name='vega.BusEvent.settlePosition', index=16,
      number=114, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='settleDistressed', full_name='vega.BusEvent.settleDistressed', index=17,
      number=115, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='marketCreated', full_name='vega.BusEvent.marketCreated', index=18,
      number=116, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='asset', full_name='vega.BusEvent.asset', index=19,
      number=117, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='marketTick', full_name='vega.BusEvent.marketTick', index=20,
      number=118, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='withdrawal', full_name='vega.BusEvent.withdrawal', index=21,
      number=119, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deposit', full_name='vega.BusEvent.deposit', index=22,
      number=120, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auction', full_name='vega.BusEvent.auction', index=23,
      number=121, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='riskFactor', full_name='vega.BusEvent.riskFactor', index=24,
      number=122, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='networkParameter', full_name='vega.BusEvent.networkParameter', index=25,
      number=123, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market', full_name='vega.BusEvent.market', index=26,
      number=1001, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='event', full_name='vega.BusEvent.event',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=858,
  serialized_end=1912,
)

_TRANSFERRESPONSES.fields_by_name['responses'].message_type = proto_dot_vega__pb2._TRANSFERRESPONSE
_SETTLEPOSITION.fields_by_name['tradeSettlements'].message_type = _TRADESETTLEMENT
_AUCTIONEVENT.fields_by_name['trigger'].enum_type = proto_dot_vega__pb2._AUCTIONTRIGGER
_BUSEVENT.fields_by_name['type'].enum_type = _BUSEVENTTYPE
_BUSEVENT.fields_by_name['timeUpdate'].message_type = _TIMEUPDATE
_BUSEVENT.fields_by_name['transferResponses'].message_type = _TRANSFERRESPONSES
_BUSEVENT.fields_by_name['positionResolution'].message_type = _POSITIONRESOLUTION
_BUSEVENT.fields_by_name['order'].message_type = proto_dot_vega__pb2._ORDER
_BUSEVENT.fields_by_name['account'].message_type = proto_dot_vega__pb2._ACCOUNT
_BUSEVENT.fields_by_name['party'].message_type = proto_dot_vega__pb2._PARTY
_BUSEVENT.fields_by_name['trade'].message_type = proto_dot_vega__pb2._TRADE
_BUSEVENT.fields_by_name['marginLevels'].message_type = proto_dot_vega__pb2._MARGINLEVELS
_BUSEVENT.fields_by_name['proposal'].message_type = proto_dot_governance__pb2._PROPOSAL
_BUSEVENT.fields_by_name['vote'].message_type = proto_dot_governance__pb2._VOTE
_BUSEVENT.fields_by_name['marketData'].message_type = proto_dot_vega__pb2._MARKETDATA
_BUSEVENT.fields_by_name['nodeSignature'].message_type = proto_dot_vega__pb2._NODESIGNATURE
_BUSEVENT.fields_by_name['lossSocialization'].message_type = _LOSSSOCIALIZATION
_BUSEVENT.fields_by_name['settlePosition'].message_type = _SETTLEPOSITION
_BUSEVENT.fields_by_name['settleDistressed'].message_type = _SETTLEDISTRESSED
_BUSEVENT.fields_by_name['marketCreated'].message_type = proto_dot_markets__pb2._MARKET
_BUSEVENT.fields_by_name['asset'].message_type = proto_dot_assets__pb2._ASSET
_BUSEVENT.fields_by_name['marketTick'].message_type = _MARKETTICK
_BUSEVENT.fields_by_name['withdrawal'].message_type = proto_dot_vega__pb2._WITHDRAWAL
_BUSEVENT.fields_by_name['deposit'].message_type = proto_dot_vega__pb2._DEPOSIT
_BUSEVENT.fields_by_name['auction'].message_type = _AUCTIONEVENT
_BUSEVENT.fields_by_name['riskFactor'].message_type = proto_dot_vega__pb2._RISKFACTOR
_BUSEVENT.fields_by_name['networkParameter'].message_type = proto_dot_vega__pb2._NETWORKPARAMETER
_BUSEVENT.fields_by_name['market'].message_type = _MARKETEVENT
_BUSEVENT.oneofs_by_name['event'].fields.append(
  _BUSEVENT.fields_by_name['timeUpdate'])
_BUSEVENT.fields_by_name['timeUpdate'].containing_oneof = _BUSEVENT.oneofs_by_name['event']
_BUSEVENT.oneofs_by_name['event'].fields.append(
  _BUSEVENT.fields_by_name['transferResponses'])
_BUSEVENT.fields_by_name['transferResponses'].containing_oneof = _BUSEVENT.oneofs_by_name['event']
_BUSEVENT.oneofs_by_name['event'].fields.append(
  _BUSEVENT.fields_by_name['positionResolution'])
_BUSEVENT.fields_by_name['positionResolution'].containing_oneof = _BUSEVENT.oneofs_by_name['event']
_BUSEVENT.oneofs_by_name['event'].fields.append(
  _BUSEVENT.fields_by_name['order'])
_BUSEVENT.fields_by_name['order'].containing_oneof = _BUSEVENT.oneofs_by_name['event']
_BUSEVENT.oneofs_by_name['event'].fields.append(
  _BUSEVENT.fields_by_name['account'])
_BUSEVENT.fields_by_name['account'].containing_oneof = _BUSEVENT.oneofs_by_name['event']
_BUSEVENT.oneofs_by_name['event'].fields.append(
  _BUSEVENT.fields_by_name['party'])
_BUSEVENT.fields_by_name['party'].containing_oneof = _BUSEVENT.oneofs_by_name['event']
_BUSEVENT.oneofs_by_name['event'].fields.append(
  _BUSEVENT.fields_by_name['trade'])
_BUSEVENT.fields_by_name['trade'].containing_oneof = _BUSEVENT.oneofs_by_name['event']
_BUSEVENT.oneofs_by_name['event'].fields.append(
  _BUSEVENT.fields_by_name['marginLevels'])
_BUSEVENT.fields_by_name['marginLevels'].containing_oneof = _BUSEVENT.oneofs_by_name['event']
_BUSEVENT.oneofs_by_name['event'].fields.append(
  _BUSEVENT.fields_by_name['proposal'])
_BUSEVENT.fields_by_name['proposal'].containing_oneof = _BUSEVENT.oneofs_by_name['event']
_BUSEVENT.oneofs_by_name['event'].fields.append(
  _BUSEVENT.fields_by_name['vote'])
_BUSEVENT.fields_by_name['vote'].containing_oneof = _BUSEVENT.oneofs_by_name['event']
_BUSEVENT.oneofs_by_name['event'].fields.append(
  _BUSEVENT.fields_by_name['marketData'])
_BUSEVENT.fields_by_name['marketData'].containing_oneof = _BUSEVENT.oneofs_by_name['event']
_BUSEVENT.oneofs_by_name['event'].fields.append(
  _BUSEVENT.fields_by_name['nodeSignature'])
_BUSEVENT.fields_by_name['nodeSignature'].containing_oneof = _BUSEVENT.oneofs_by_name['event']
_BUSEVENT.oneofs_by_name['event'].fields.append(
  _BUSEVENT.fields_by_name['lossSocialization'])
_BUSEVENT.fields_by_name['lossSocialization'].containing_oneof = _BUSEVENT.oneofs_by_name['event']
_BUSEVENT.oneofs_by_name['event'].fields.append(
  _BUSEVENT.fields_by_name['settlePosition'])
_BUSEVENT.fields_by_name['settlePosition'].containing_oneof = _BUSEVENT.oneofs_by_name['event']
_BUSEVENT.oneofs_by_name['event'].fields.append(
  _BUSEVENT.fields_by_name['settleDistressed'])
_BUSEVENT.fields_by_name['settleDistressed'].containing_oneof = _BUSEVENT.oneofs_by_name['event']
_BUSEVENT.oneofs_by_name['event'].fields.append(
  _BUSEVENT.fields_by_name['marketCreated'])
_BUSEVENT.fields_by_name['marketCreated'].containing_oneof = _BUSEVENT.oneofs_by_name['event']
_BUSEVENT.oneofs_by_name['event'].fields.append(
  _BUSEVENT.fields_by_name['asset'])
_BUSEVENT.fields_by_name['asset'].containing_oneof = _BUSEVENT.oneofs_by_name['event']
_BUSEVENT.oneofs_by_name['event'].fields.append(
  _BUSEVENT.fields_by_name['marketTick'])
_BUSEVENT.fields_by_name['marketTick'].containing_oneof = _BUSEVENT.oneofs_by_name['event']
_BUSEVENT.oneofs_by_name['event'].fields.append(
  _BUSEVENT.fields_by_name['withdrawal'])
_BUSEVENT.fields_by_name['withdrawal'].containing_oneof = _BUSEVENT.oneofs_by_name['event']
_BUSEVENT.oneofs_by_name['event'].fields.append(
  _BUSEVENT.fields_by_name['deposit'])
_BUSEVENT.fields_by_name['deposit'].containing_oneof = _BUSEVENT.oneofs_by_name['event']
_BUSEVENT.oneofs_by_name['event'].fields.append(
  _BUSEVENT.fields_by_name['auction'])
_BUSEVENT.fields_by_name['auction'].containing_oneof = _BUSEVENT.oneofs_by_name['event']
_BUSEVENT.oneofs_by_name['event'].fields.append(
  _BUSEVENT.fields_by_name['riskFactor'])
_BUSEVENT.fields_by_name['riskFactor'].containing_oneof = _BUSEVENT.oneofs_by_name['event']
_BUSEVENT.oneofs_by_name['event'].fields.append(
  _BUSEVENT.fields_by_name['networkParameter'])
_BUSEVENT.fields_by_name['networkParameter'].containing_oneof = _BUSEVENT.oneofs_by_name['event']
_BUSEVENT.oneofs_by_name['event'].fields.append(
  _BUSEVENT.fields_by_name['market'])
_BUSEVENT.fields_by_name['market'].containing_oneof = _BUSEVENT.oneofs_by_name['event']
DESCRIPTOR.message_types_by_name['MarketEvent'] = _MARKETEVENT
DESCRIPTOR.message_types_by_name['TimeUpdate'] = _TIMEUPDATE
DESCRIPTOR.message_types_by_name['TransferResponses'] = _TRANSFERRESPONSES
DESCRIPTOR.message_types_by_name['PositionResolution'] = _POSITIONRESOLUTION
DESCRIPTOR.message_types_by_name['LossSocialization'] = _LOSSSOCIALIZATION
DESCRIPTOR.message_types_by_name['TradeSettlement'] = _TRADESETTLEMENT
DESCRIPTOR.message_types_by_name['SettlePosition'] = _SETTLEPOSITION
DESCRIPTOR.message_types_by_name['SettleDistressed'] = _SETTLEDISTRESSED
DESCRIPTOR.message_types_by_name['MarketTick'] = _MARKETTICK
DESCRIPTOR.message_types_by_name['AuctionEvent'] = _AUCTIONEVENT
DESCRIPTOR.message_types_by_name['BusEvent'] = _BUSEVENT
DESCRIPTOR.enum_types_by_name['BusEventType'] = _BUSEVENTTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MarketEvent = _reflection.GeneratedProtocolMessageType('MarketEvent', (_message.Message,), {
  'DESCRIPTOR' : _MARKETEVENT,
  '__module__' : 'proto.events_pb2'
  # @@protoc_insertion_point(class_scope:vega.MarketEvent)
  })
_sym_db.RegisterMessage(MarketEvent)

TimeUpdate = _reflection.GeneratedProtocolMessageType('TimeUpdate', (_message.Message,), {
  'DESCRIPTOR' : _TIMEUPDATE,
  '__module__' : 'proto.events_pb2'
  # @@protoc_insertion_point(class_scope:vega.TimeUpdate)
  })
_sym_db.RegisterMessage(TimeUpdate)

TransferResponses = _reflection.GeneratedProtocolMessageType('TransferResponses', (_message.Message,), {
  'DESCRIPTOR' : _TRANSFERRESPONSES,
  '__module__' : 'proto.events_pb2'
  # @@protoc_insertion_point(class_scope:vega.TransferResponses)
  })
_sym_db.RegisterMessage(TransferResponses)

PositionResolution = _reflection.GeneratedProtocolMessageType('PositionResolution', (_message.Message,), {
  'DESCRIPTOR' : _POSITIONRESOLUTION,
  '__module__' : 'proto.events_pb2'
  # @@protoc_insertion_point(class_scope:vega.PositionResolution)
  })
_sym_db.RegisterMessage(PositionResolution)

LossSocialization = _reflection.GeneratedProtocolMessageType('LossSocialization', (_message.Message,), {
  'DESCRIPTOR' : _LOSSSOCIALIZATION,
  '__module__' : 'proto.events_pb2'
  # @@protoc_insertion_point(class_scope:vega.LossSocialization)
  })
_sym_db.RegisterMessage(LossSocialization)

TradeSettlement = _reflection.GeneratedProtocolMessageType('TradeSettlement', (_message.Message,), {
  'DESCRIPTOR' : _TRADESETTLEMENT,
  '__module__' : 'proto.events_pb2'
  # @@protoc_insertion_point(class_scope:vega.TradeSettlement)
  })
_sym_db.RegisterMessage(TradeSettlement)

SettlePosition = _reflection.GeneratedProtocolMessageType('SettlePosition', (_message.Message,), {
  'DESCRIPTOR' : _SETTLEPOSITION,
  '__module__' : 'proto.events_pb2'
  # @@protoc_insertion_point(class_scope:vega.SettlePosition)
  })
_sym_db.RegisterMessage(SettlePosition)

SettleDistressed = _reflection.GeneratedProtocolMessageType('SettleDistressed', (_message.Message,), {
  'DESCRIPTOR' : _SETTLEDISTRESSED,
  '__module__' : 'proto.events_pb2'
  # @@protoc_insertion_point(class_scope:vega.SettleDistressed)
  })
_sym_db.RegisterMessage(SettleDistressed)

MarketTick = _reflection.GeneratedProtocolMessageType('MarketTick', (_message.Message,), {
  'DESCRIPTOR' : _MARKETTICK,
  '__module__' : 'proto.events_pb2'
  # @@protoc_insertion_point(class_scope:vega.MarketTick)
  })
_sym_db.RegisterMessage(MarketTick)

AuctionEvent = _reflection.GeneratedProtocolMessageType('AuctionEvent', (_message.Message,), {
  'DESCRIPTOR' : _AUCTIONEVENT,
  '__module__' : 'proto.events_pb2'
  # @@protoc_insertion_point(class_scope:vega.AuctionEvent)
  })
_sym_db.RegisterMessage(AuctionEvent)

BusEvent = _reflection.GeneratedProtocolMessageType('BusEvent', (_message.Message,), {
  'DESCRIPTOR' : _BUSEVENT,
  '__module__' : 'proto.events_pb2'
  # @@protoc_insertion_point(class_scope:vega.BusEvent)
  })
_sym_db.RegisterMessage(BusEvent)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
